/*globals require, window*/

require([
    'jquery',
    'testsuite/qunit',
    'testsuite/qunit-fixture!de_epages/shop/ui/greeter-test',

    'de_epages/shop/ui/greeter'
], function ($, QUnit, fixture) {
    'use strict';


    QUnit.module('de_epages/shop/ui/greeter', {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest('check presence/existence of methods', 3, function () {
        // check prototype methods
        $.each(['_init', 'render', 'destroy'], function (i, fn) {
            QUnit.equal(
                $.isFunction($.ui.shopUiGreeter.prototype[fn]),
                true,
                '$.isFunction(' + fn + '):'
            );

        });

        // run tests
        QUnit.start();
    });

    QUnit.asyncTest('test widget functionalities', 9, function () {
        var header = [{
                start: 0,
                end: 10,
                translation: '{0to10Greeting}'
            }, {
                start: 10,
                end: 12,
                translation: '{10to12Greeting}'
            }, {
                start: 12,
                end: 14,
                translation: '{12to14Greeting}'
            }, {
                start: 14,
                end: 18,
                translation: '{14to18Greeting}'
            }, {
                start: 18,
                end: 24,
                translation: '{18to24Greeting}'
            }],

            $containerElem = de_epages('.ep-dashboard-greeter-container'),
            $subtitleElem,
            i,

            checkTimePeriods = function(period) {
                // overwrite getHourse method of Date object
                window.Date.prototype.getHours = function() {
                    return header[period].start + 1;
                };

                $containerElem.shopUiGreeter('render');
                // debugger;
                QUnit.ok((new RegExp(header[period].translation)).test($containerElem.find('h2').html()) === true, 'header text "' + header[period].translation + '" was found');
            };

        // instantiate widget
        $containerElem.shopUiGreeter({
            header: header,
            subtitle: '{GreetingSubtitle}'
        });

        // start testing
        QUnit.equal(
            $containerElem.data('uiShopUiGreeter') instanceof $.Widget,
            true,
            "shopUiGreeter widget was created and is an instance of jQuery.Widget"
        );

        // check sub text
        $subtitleElem = $containerElem.find('span');
        QUnit.ok(/GreetingSubtitle/.test($subtitleElem.html()) === true, 'sub text "GreetingSubtile" was found');

        // check time periods
        for (i=0; i<header.length; i++) {
            checkTimePeriods(i);
        }

        // check destroy method
        $containerElem.shopUiGreeter('destroy');
        QUnit.equal(
            $containerElem.data('uiShopUiGreeter'),
            undefined,
            "shopUiGreeter widget was destroyed"
        );
        QUnit.ok($containerElem.is(':empty') === true, 'content created by widget was removed again');

        // run tests
        QUnit.start();
    });
});